@@ -1,11 +1,11 @@
-mod ho_archive;
-mod mast;
-mod section;
-mod table;
-mod asset;
-mod read;
-mod write;
-mod math;
+pub mod ho_archive;
+pub mod mast;
+pub mod section;
+pub mod table;
+pub mod asset;
+pub mod read;
+pub mod write;
+pub mod math;
 
 
 pub fn create_archive(path: String) -> ho_archive::ho_archive{
